.. highlight:: shell

=========================
Rozwijanie oprogramowania
=========================

Cenimy sobie wszystkie uwagi, nawet te krytyczne. Każda z nich może pomóc, podobnie
każdy z nas może zostać współautorem niniejszego oprogramowania.

Możesz dołożyć się do tego projektu na różne sposoby:

Zgłaszanie błędów
~~~~~~~~~~~~~~~~~

Zgłaszaj błędy w oprogramowaniu pod adresem https://github.com/iplweb/bpp/issues.

Jeżeli zgłaszasz bład, prosimy, opisz:

* Twój system operacyjny i wersję przeglądarki WWW,
* szczegóły dotyczące konfiguracji Twojego komputera, które mogą pomóc w powieleniu a następnie usunięciu błędu,
* szczegółową instrukcję krok-po-kroku jak spowodować wystąpienie błędu

Naprawianie błędów
~~~~~~~~~~~~~~~~~~

Przejrzyj zgłoszenia na GitHub w poszukiwaniu błędów, które możesz naprawić.

Zaimplementuj nowe funkcje
~~~~~~~~~~~~~~~~~~~~~~~~~~

Przejrzyj zgłoszenia na GitHub w poszukiwaniu zgłoszeń zawierających zapotrzebowanie
na nowe funkcje. Wszystko, co oznaczone "enhancement" lub "help wanted" czeka na
osobę, która się tym zajmie.

Napisz dokumentację
~~~~~~~~~~~~~~~~~~~

BPP zawsze może skorzystać z nowej dokumentacji, bądź to w formie instrukcji,
docstrings lub artykułów na sieci, prezentacji itp.

Zgłoś uwagi
~~~~~~~~~~~

Najlepszy sposób na zgłoszenie swoich uwag to wypełnienie formularza pod adresem
 https://github.com/iplweb/bpp/issues.

Jeżeli proponujesz nową funkcję:

* Wyjaśnij, w jaki sposób ma działać
* Pamiętaj, ze ten projekt rozwijany jest na zasadach opensource i Twój wkład
  jest mile widziany
